telephonyserverplugins/ctsydispatchlayer/test/dispatchertests/dispatchsrc/cctsyphonebookonfu.cpp
branchRCL_3
changeset 14 7ef16719d8cb
parent 0 3553901f7fa8
child 24 6638e7f4bd8f
--- a/telephonyserverplugins/ctsydispatchlayer/test/dispatchertests/dispatchsrc/cctsyphonebookonfu.cpp	Fri Feb 19 23:59:33 2010 +0200
+++ b/telephonyserverplugins/ctsydispatchlayer/test/dispatchertests/dispatchsrc/cctsyphonebookonfu.cpp	Fri Mar 12 15:49:38 2010 +0200
@@ -229,6 +229,9 @@
 	OpenEtelServerL(EUseExtendedError);
 	CleanupStack::PushL(TCleanupItem(Cleanup,this));
 	OpenPhoneL();
+    RMobilePhoneBookStore adnPhoneBookStore;
+    CleanupClosePushL(adnPhoneBookStore);
+    OpenCachingPhoneBookL(DispatcherPhonebook::EIccAdn,adnPhoneBookStore,KErrNone);
 	
 	RMobileONStore onStore;
 	TInt ret = onStore.Open(iPhone);
@@ -378,7 +381,7 @@
 	
 	AssertMockLtsyStatusL();
     
-	CleanupStack::PopAndDestroy(4, this); // completeData, expectData, onStore, this
+	CleanupStack::PopAndDestroy(5, this); // completeData, expectData, onStore, adnPhoneBookStore, this
 	}
 
 /**
@@ -395,6 +398,9 @@
 	OpenEtelServerL(EUseExtendedError);
 	CleanupStack::PushL(TCleanupItem(Cleanup,this));
 	OpenPhoneL();
+    RMobilePhoneBookStore adnPhoneBookStore;
+    CleanupClosePushL(adnPhoneBookStore);
+    OpenCachingPhoneBookL(DispatcherPhonebook::EIccAdn,adnPhoneBookStore,KErrNone);
 	
 	RMobileONStore onStore;
 	TInt ret = onStore.Open(iPhone);
@@ -470,7 +476,7 @@
 	
 	AssertMockLtsyStatusL();
 
-	CleanupStack::PopAndDestroy(3, this); // completeData, onStore, this
+	CleanupStack::PopAndDestroy(4, this); // completeData, onStore, adnPhoneBookStore, this
 	}
 
 	
@@ -492,6 +498,9 @@
 	OpenEtelServerL(EUseExtendedError);
 	CleanupStack::PushL(TCleanupItem(Cleanup,this));
 	OpenPhoneL();
+    RMobilePhoneBookStore adnPhoneBookStore;
+    CleanupClosePushL(adnPhoneBookStore);
+    OpenCachingPhoneBookL(DispatcherPhonebook::EIccAdn,adnPhoneBookStore,KErrNone);
 	
 	RMobileONStore onStore;
 	TInt ret = onStore.Open(iPhone);
@@ -573,7 +582,7 @@
 	ASSERT_EQUALS(KErrNone, mockLtsyStatus.Int());
 	AssertMockLtsyStatusL();
 	
-	CleanupStack::PopAndDestroy(3, this); // data, onStore, this
+	CleanupStack::PopAndDestroy(4, this); // data, onStore, adnPhoneBookStore, this
 
 	}